@@ -4,7 +4,7 @@ Display song/video and control MPRIS compatible players.
 
 There are two ways to control the media player. Either by clicking with a mouse
 button in the text information or by using buttons. For former you have
-to define the button parameters in the i3status config.
+to define the button parameters in your config.
 
 Configuration parameters:
     button_next: mouse button to play the next entry (default 4)
@@ -15,11 +15,11 @@ Configuration parameters:
         (default '{previous}{toggle}{next} {state} [{artist} - ][{title}]')
     format_none: define output if no player is running
         (default 'no player running')
-    icon_next: text for the next button in the button control panel (default '»')
-    icon_pause: text for the pause button in the button control panel (default '▮')
-    icon_play: text for the play button in the button control panel (default '▶')
-    icon_previous: text for the previous button in the button control panel (default '«')
-    icon_stop: text for the stop button in the button control panel (default '◾')
+    icon_next: specify icon for next button (default ' » ')
+    icon_pause: specify icon for pause button (default ' ▮ ')
+    icon_play: specify icon for play button (default ' ▶ ')
+    icon_previous: specify icon for previous button (default ' « ')
+    icon_stop: specify icon for stop button (default ' ◾ ')
     player_priority: priority of the players.
         Keep in mind that the state has a higher priority than
         player_priority. So when player_priority is "[mpd, bomi]" and mpd is
@@ -28,7 +28,7 @@ Configuration parameters:
     state_play: text for placeholder {state} when song is playing (default '▶')
     state_stop: text for placeholder {state} when song is stopped (default '◾')
 
-Format of status string placeholders:
+Format placeholders:
     {album} album name
     {artist} artiste name (first one)
     {length} time duration of the song
@@ -37,7 +37,7 @@ Format of status string placeholders:
     {time} played time of the song
     {title} name of the song
 
-Format of button placeholders:
+Button placeholders:
     {next} play the next title
     {pause} pause the player
     {play} play the player
@@ -53,59 +53,44 @@ Color options:
     color_stopped: song is stopped, defaults to color_bad
 
 Requires:
-    pydbus: python library module
+    pydbus: pythonic d-bus library
 
-i3status.conf example:
+Tested players:
+    bomi: powerful and easy-to-use gui multimedia player based on mpv
+    cantata: qt5 client for the music player daemon (mpd)
+    mpdris2: mpris2 support for mpd
+    vlc: multi-platform mpeg, vcd/dvd, and divx player
 
+Examples:
 ```
 mpris {
     format = "{previous}{play}{next} {player}: {state} [[{artist} - {title}]|[{title}]]"
     format_none = "no player"
     player_priority = "[mpd, cantata, vlc, bomi, *]"
 }
-```
 
 only show information from mpd and vlc, but mpd has a higher priority:
-
-```
 mpris {
     player_priority = "[mpd, vlc]"
 }
-```
 
 show information of all players, but mpd and vlc have the highest priority:
-
-```
 mpris {
     player_priority = "[mpd, vlc, *]"
 }
-```
 
 vlc has the lowest priority:
-
-```
 mpris {
     player_priority = "[*, vlc]"
 }
 ```
 
-Tested players:
-    bomi
-    Cantata
-    mpDris2 (mpris extension for mpd)
-    vlc
-
 @author Moritz Lüdecke, tobes, valdur55
 
 SAMPLE OUTPUT
 [
-    {'color': '#00FF00', 'index': 'previous', 'min_width': 20,
-     'align': 'center', 'full_text': u'\xab'},
-    {'color': '#00FF00', 'index': 'toggle', 'min_width': 20,
-     'align': 'center', 'full_text': u'\u25ae'},
-    {'color': '#00FF00', 'index': 'next', 'min_width': 20,
-     'align': 'center', 'full_text': u'\xbb '},
-    {'full_text': u'\u25b6 Happy Mondays - Fat Lady Wrestlers'}
+    {'color': '#00FF00', 'full_text': u'\xab \u25ae \xbb \u25b6 '},
+    {'color': '#00FF00', 'full_text': u'Happy Mondays - Fat Lady Wrestlers'}
 ]
 """
 
@@ -151,11 +136,11 @@ class Py3status:
     button_toggle = 1
     format = "{previous}{toggle}{next} {state} [{artist} - ][{title}]"
     format_none = "no player running"
-    icon_next = u"»"
-    icon_pause = u"▮"
-    icon_play = u"▶"
-    icon_previous = u"«"
-    icon_stop = u"◾"
+    icon_next = u" » "
+    icon_pause = u" ▮ "
+    icon_play = u" ▶ "
+    icon_previous = u" « "
+    icon_stop = u" ◾ "
     player_priority = []
     state_pause = u"▮"
     state_play = u"▶"
@@ -313,8 +298,6 @@ class Py3status:
                 "color": color,
                 "full_text": control_state["icon"],
                 "index": button,
-                "min_width": 20,
-                "align": "center",
             }
 
         return response
